==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/pt_PT.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentários",
    "Edit comment" : "Editar comentário",
    "Delete comment" : "Eliminar comentário",
    "New comment …" : "Novo comentário …",
    "Post" : "Publicar",
    "Cancel" : "Cancelar",
    "[Deleted user]" : "[Utilizador eliminado]",
    "No comments yet, start the conversation!" : "Ainda sem comentários, inicie uma conversação!",
    "More comments …" : "Mais comentários ...",
    "Save" : "Guardar",
    "Allowed characters {count} of {max}" : "{count} de {max} caracteres restantes",
    "Error occurred while updating comment with id {id}" : "Ocorreu um erro ao tentar atualizar o comentário com o id {id}",
    "Error occurred while posting comment" : "Ocorreu um erro ao tentar publicar o comentário",
    "_%n unread comment_::_%n unread comments_" : ["%n comentários por ler","%n comentários por ler"],
    "Comment" : "Comentário",
    "You commented" : "Comentou",
    "%1$s commented" : "%1$s comentou",
    "{author} commented" : "{author} comentou",
    "You commented on %1$s" : "Comentaste em %1$s",
    "You commented on {file}" : "Comentaste em {file}",
    "%1$s commented on %2$s" : "%1$s comentou %2$s",
    "{author} commented on {file}" : "{author} comentou em {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentários</strong> aos ficheiros",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Foste mencionado em “%s”, num comentário de um utilizador que foi entretanto removido",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Foste mencionado e, “{file}”, num comentário de um utilizador que foi entretanto removido",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s mencionou-te num comentário em “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} mencionou-te num comentário em “{file}”",
    "Unknown user" : "Utilizador desconhecido",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Um utilizador (agora removido) mencionou-te num comentário em “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Um utilizador (agora removido) mencionou-te num comentário em “{file}”"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/pt_PT.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Editar comentário",
    "Delete comment" : "Eliminar comentário",
    "New comment …" : "Novo comentário …",
    "Post" : "Publicar",
    "Cancel" : "Cancelar",
    "[Deleted user]" : "[Utilizador eliminado]",
    "Comments" : "Comentários",
    "No comments yet, start the conversation!" : "Ainda sem comentários, inicie uma conversação!",
    "More comments …" : "Mais comentários ...",
    "Save" : "Guardar",
    "Allowed characters {count} of {max}" : "{count} de {max} caracteres restantes",
    "Error occurred while updating comment with id {id}" : "Ocorreu um erro ao tentar atualizar o comentário com o id {id}",
    "Error occurred while posting comment" : "Ocorreu um erro ao tentar publicar o comentário",
    "_%n unread comment_::_%n unread comments_" : ["%n comentários por ler","%n comentários por ler"],
    "Comment" : "Comentário",
    "You commented" : "Comentou",
    "%1$s commented" : "%1$s comentou",
    "{author} commented" : "{author} comentou",
    "You commented on %1$s" : "Comentaste em %1$s",
    "You commented on {file}" : "Comentaste em {file}",
    "%1$s commented on %2$s" : "%1$s comentou %2$s",
    "{author} commented on {file}" : "{author} comentou em {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentários</strong> aos ficheiros",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Foste mencionado e, “{file}”, num comentário de um utilizador que foi entretanto removido",
    "{user} mentioned you in a comment on “{file}”" : "{user} mencionou-te num comentário em “{file}”",
    "Unknown user" : "Utilizador desconhecido",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Um utilizador (agora removido) mencionou-te num comentário em “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Um utilizador (agora removido) mencionou-te num comentário em “{file}”",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s mencionou-te num comentário em “%2$s”",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Foste mencionado em “%s”, num comentário de um utilizador que foi entretanto removido"
},
"nplurals=2; plural=(n != 1);");
